@@ -4,8 +4,8 @@
 
 ;; Author:  Enrique Kessler Martínez
 ;; Keywords: convenience project management
-;; Package-Version: 20250926.603
-;; Package-Revision: 8067e2c0ca29
+;; Package-Version: 20260117.813
+;; Package-Revision: 2b3fa36fd3a1
 ;; Package-Requires: ((emacs "28.1") (consult "0.17") (project "0.8.1"))
 ;; URL: https://github.com/Qkessler/consult-project-extra
 
@@ -116,10 +116,12 @@ When no project is found and MAY-PROMPT is non-nil ask the user."
   "Find-file concatenating root with CANDIDATE."
   (consult--file-action (concat (consult--project-root) candidate)))
 
-;; The default `consult--source-project-buffer' has the ?p as narrow key,
+;; The default `consult-source-project-buffer' has the ?p as narrow key,
 ;; and therefore is in conflict with `consult-project-extra--source-project'.
 (defvar consult-project-extra--source-buffer
-  (let* ((unmodified consult--source-project-buffer)
+  (let* ((unmodified (if (boundp 'consult-source-project-buffer)
+                         consult-source-project-buffer
+                       consult--source-project-buffer))
          (modified-source (plist-put (plist-put unmodified :hidden nil) :narrow ?b)))
     modified-source))
 
